@@ -195,7 +195,7 @@ class BingSpider():
     
 
 
-    def fetch_items(self, keyword, start_page:int = 0, end_page: int = 1, item_num:int = None, **kwargs):
+    def search(self, keyword, start_page:int = 0, end_page: int = 1, item_num:int = None, **kwargs):
         """
         传入一个关键词，返回一个item list
         @keyword: 关键词
